@@ -136,7 +136,8 @@ failure protocol (FP::Abstract::Failure) instead?
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
