@@ -213,7 +213,8 @@ our $immutable= 1; # whether pairs are to be made immutable
 
     sub stream {
         @_==1 or die "wrong number of arguments";
-        lazy { $_[0] }
+        my ($l)= @_;
+        lazy { $l }
     }
 
     sub preferred_fold {
@@ -555,6 +556,7 @@ sub is_list ($) {
       }
       : ''))
 }
+*FP::List::List::is_proper_sequence= \&is_list;
 
 TEST { is_list cons 1, cons 2, null } 1;
 TEST { is_list cons 1, cons 2, 3 } '';
