@@ -112,6 +112,7 @@ package FP::Predicates;
 
               is_filename
               is_sequence
+              is_proper_sequence
               is_seq
 
               less_than
@@ -436,6 +437,13 @@ sub is_sequence ($) {
         or fail "is_sequence", $v
 }
 
+sub is_proper_sequence ($) {
+    my $v= force $_[0];
+    (UNIVERSAL::isa($v, "FP::Abstract::Sequence")
+     and $v->is_proper_sequence)
+        or fail "is_sequence", $v
+}
+
 # Like is_sequence but only returns true when the sequence isn't empty
 sub is_seq ($) {
     my $v= force $_[0];
