@@ -124,6 +124,8 @@ use FP::HashSet qw(hashset_union);
 use FP::Hash qw(hash_xref);
 use FP::Repl::StackPlus;
 use FP::Lazy;
+use FP::Show;
+
 
 sub maybe_tty {
     my $path= "/dev/tty";
@@ -381,7 +383,6 @@ sub formatter {
              )
          },
          s=> sub {
-             require FP::Show;
              my $z=1;
              (
               join "",
@@ -389,7 +390,7 @@ sub formatter {
                   my $VARX= ($$self[DoKeepResultsInVARX] and not $terse) ?
                     '$VAR'.$z++.' = '
                       : '';
-                  $VARX . FP::Show::show($_). ";\n"
+                  $VARX . show($_). ";\n"
               } @_
              )
          },
@@ -406,7 +407,7 @@ sub formatter {
                  $res= Data::Dumper::Dumper(@v);
                  1
              } || do {
-                 warn "Data::Dumper: $@";
+                 warn "Data::Dumper: ".show($@);
              };
              $res
          }
@@ -446,10 +447,10 @@ sub viewers {
                 $o->xfinish;
                 1
             } || do {
-                my $e= $@;
-                unless ($e=~ /broken pipe/i) {
+                my $estr= show($@);
+                unless ($estr=~ /broken pipe/i) {
                     print $ERROR "error piping to pager ".
-                      "$pagercmd: $e\n"
+                      "$pagercmd: $estr\n"
                         or die $!;
                 }
             };
@@ -918,7 +919,7 @@ sub run {
                   $maybe_lexical_persistence->prelude("");
                 1
             } || do {
-                print $ERROR "Could not enable lexical persistence: $@";
+                print $ERROR "Could not enable lexical persistence: ".show($@);
                 0
             }
         };
@@ -963,6 +964,12 @@ sub run {
                                 my ($maybe_frameno)=
                                   $rest=~ /^\s*(\d+)?\s*\z/
                                     or die "expecting digits or no argument, got '$cmd'";
+                                local $FP::Lazy::allow_access= 1;
+                                # ^ XX should be generalized, not just
+                                # for FP::Lazy; or alternatively, use
+                                # overload::StrVal instead of
+                                # stringification in the backtrace
+                                # library.
                                 print $OUTPUT $stack->backtrace ($maybe_frameno
                                                                  // $frameno);
                                 $rest=""; # XX HACK; also, really
@@ -1105,7 +1112,7 @@ sub run {
 
                             1
                         } || do {
-                            print $ERROR "$@";
+                            print $ERROR "error handling command $cmd: ".show($@);
                             redo READ;
                         }
                     }
@@ -1156,15 +1163,12 @@ sub run {
 
                         &$view_string(do {
                             if (ref $error or $error) {
-                                # XX todo: only do can in the case of
-                                # ref; but, remove this code anyway,
-                                # use FP::Show now?
                                 my $err= (UNIVERSAL::can($error,"plain") ?
                                           # error in plaintext; XX:
                                           # change to better
                                           # thought-out protocol?
                                           $error->plain
-                                          : "$error");
+                                          : show($error));
                                 chomp $err;
                                 $err."\n"; # no prefix? no safe way to differentiate.
                             } else {
@@ -1211,7 +1215,7 @@ sub run {
                 $f->xputback(0600);
             };
             if (ref $@ or $@) {
-                warn "could not write history file: $@"
+                warn "could not write history file: ".show($@)
             }
         }
         $SIG{INT}= defined($oldsigint)? $oldsigint : "DEFAULT";
